@@ -91,7 +91,7 @@ static const backend_table_t g_backends[] = {
 	{"idive",       DC_FAMILY_DIVESYSTEM_IDIVE,    0x03},
 	{"cochran",     DC_FAMILY_COCHRAN_COMMANDER,   0},
 	{"divecomputereu", DC_FAMILY_TECDIVING_DIVECOMPUTEREU, 0},
-	{"mclean",      DC_FAMILY_MCLEAN_EXTREME,      0},
+	{"extreme",     DC_FAMILY_MCLEAN_EXTREME,      0},
 	{"lynx",        DC_FAMILY_LIQUIVISION_LYNX,    0},
 	{"sp2",         DC_FAMILY_SPORASUB_SP2,        0},
 
