@@ -459,6 +459,7 @@ static const oceanic_common_version_t versions[] = {
 	{"AMPHOAIR \0\0 512K", 0,      &tusa_zenair_layout},
 	{"VOYAGE2G \0\0 512K", 0,      &tusa_zenair_layout},
 	{"TUSTALIS \0\0 512K", 0,      &tusa_zenair_layout},
+	{"AMPHOS20 \0\0 512K", 0,      &tusa_zenair_layout},
 
 	{"REACPRO2 \0\0 512K", 0,      &oceanic_reactpro_layout},
 
@@ -906,7 +907,7 @@ oceanic_atom2_device_open (dc_device_t **out, dc_context_t *context, dc_iostream
 	}
 
 	if (dc_iostream_get_transport (device->iostream) == DC_TRANSPORT_BLE &&
-		model != PROPLUSX && model != SAGE && model != BEACON) {
+		model != PROPLUSX && model != I750TC && model != SAGE && model != BEACON) {
 		status = oceanic_atom2_ble_handshake(device);
 		if (status != DC_STATUS_SUCCESS) {
 			goto error_free;
