@@ -99,6 +99,7 @@
 #define VEO40       0x4654
 #define WISDOM4     0x4655
 #define PROPLUS4    0x4656
+#define AMPHOS2     0x4657
 #define BEACON      0x4742
 #define I470TC      0x4743
 
@@ -316,6 +317,7 @@ oceanic_atom2_parser_get_datetime (dc_parser_t *abstract, dc_datetime_t *datetim
 		case AMPHOSAIR:
 		case VOYAGER2G:
 		case TALIS:
+		case AMPHOS2:
 			datetime->year   = (p[3] & 0x1F) + 2000;
 			datetime->month  = (p[7] & 0xF0) >> 4;
 			datetime->day    = ((p[3] & 0x80) >> 3) + ((p[5] & 0xF0) >> 4);
@@ -949,7 +951,8 @@ oceanic_atom2_parser_samples_foreach (dc_parser_t *abstract, dc_sample_callback_
 						parser->model == PROPLUS4 || parser->model == WISDOM4)
 						sign = (~data[offset + 5] & 0x04) >> 2;
 					else if (parser->model == VOYAGER2G || parser->model == AMPHOS ||
-						parser->model == AMPHOSAIR || parser->model == ZENAIR)
+						parser->model == AMPHOSAIR || parser->model == ZENAIR ||
+						parser->model == AMPHOS2)
 						sign = (data[offset + 5] & 0x04) >> 2;
 					else if (parser->model == ATOM2 || parser->model == PROPLUS21 ||
 						parser->model == EPICA || parser->model == EPICB ||
